==> hoteldruid-mod-fr_2.3.1-1.tar.gz: fr/inizio.php <==
<?php

switch ($messaggio) {

case "Menù principale dell'anno":             	$messaggio = "Menu principal de l'année"; break;
case "Inserisci una nuova prenotazione":      	$messaggio = "Insérer une nouvelle réservation"; break;
case "prenotazioni del mese di": 		$messaggio = "réservations mois de"; break;
case "visualizza": 				$messaggio = "voir"; break;
case "Gennaio":                               	$messaggio = "Janvier"; break;
case "Febbraio":                              	$messaggio = "Février"; break;
case "Marzo":                                 	$messaggio = "Mars"; break;
case "Aprile":      							$messaggio = "Avril"; break;
case "Maggio":                           		$messaggio = "Mai"; break;
case "Giugno":                            		$messaggio = "Juin"; break;
case "Luglio":                            		$messaggio = "Juillet"; break;
case "Agosto":  								$messaggio = "Août"; break;
case "Settembre":  								$messaggio = "Septembre"; break;
case "Ottobre":  								$messaggio = "Octobre"; break;
case "Novembre":  								$messaggio = "Novembre"; break;
case "Dicembre":  								$messaggio = "Décembre"; break;
case "tabella con":  				$messaggio = "tableau avec"; break;
case "tutte le prenotazioni":  					$messaggio = "toutes les réservations"; break;
case "le spese e le entrate":  					$messaggio = "dépenses et recettes"; break;
case "i periodi e le tariffe":  				$messaggio = "les périodes et les prix"; break;
case "tutti i clienti":  						$messaggio = "tous les clients"; break;
case "le regole di assegnazione":  				$messaggio = "les règles d'attribution"; break;
case "Inserisci un nuovo cliente":		$messaggio = "Insérer un nouveau client"; break;
case "Spese ed entrate":  			$messaggio = "dépenses et recettes"; break;
case "disponibilità dal":  			$messaggio = "disponibilités du"; break;
case "al":  									$messaggio = "au"; break;
case "per":  									$messaggio = "pour"; break;
case "persone":	  								$messaggio = "personnes"; break;
case "controlla":  				$messaggio = "vérifier"; break;
case "Inserisci o modifica i prezzi":  			$messaggio = "Insérer ou modifier les prix"; break;
case "Inserisci o modifica le regole di assegnazione":  $messaggio = "Insérer ou modifier les règles d'attribution"; break;
case "Configura e personalizza":				$messaggio = "Configurer et personnaliser"; break;
case "richiedi l'anno":  						$messaggio = "Aller à l'année"; break;
case "vai":  									$messaggio = "go"; break;
case "Non esiste l'anno ":  					$messaggio = "L'année "; break;
case " nel database":  							$messaggio = " n'existe pas dans la base de données"; break;
case "Crea l'anno":  							$messaggio = "Créer l'année"; break;
case "Domenica":  								$messaggio = "Dimanche"; break;
case "Lunedì":  								$messaggio = "Lundi"; break;
case "Martedì":  								$messaggio = "Mardi"; break;
case "Mercoledì":  								$messaggio = "Mercredi"; break;
case "Giovedì":  								$messaggio = "Jeudi"; break;
case "Venerdì":  								$messaggio = "Vendredi"; break;
case "Sabato":	 		 						$messaggio = "Samedi"; break;
case "come giorno di inizio/fine locazione":	$messaggio = "jour de début/fin de location"; break;
case "con periodi":  							$messaggio = "avec"; break;
case "settimanali":  							$messaggio = "périodes hebdomadaires"; break;
case "giornalieri":  							$messaggio = "périodes quotidiennes"; break;
case "e prenotazioni da":  						$messaggio = "et réservations de"; break;
case "a":  										$messaggio = "à"; break;
case "anno successivo": 			$messaggio = "année suivante"; break;
case "anni successivi":  			$messaggio = "années suivantes"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi), privilegi degli utenti e regole d'assegnazione.":  $messaggio = "Importation des réservations d'année précédente, des prix (inclus les surcoûts), des privilèges d'utilisateurs et des règles d'attribution."; break;
case "Anno ":  									$messaggio = "Année "; break;
case " creato":  								$messaggio = " créé"; break;
case "Non ci sono periodi che riguardano il ":  $messaggio = "Il n'y a aucune période concernant "; break;
case " nel ":  									$messaggio = " dans "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3":	$messaggio = ", ou le jour de la location de commencer/extrémité était différent, seulement des données au sujet des surcoûts, du dépôt, des noms des prix, des privilèges et des règles 2 et 3 d'utilisateurs des règles d'attribution ont été importées"; break;
case "Attenzione</b></font>: i periodi del ":  		$messaggio = "Attention</b></font> : les périodes de "; break;
case " finivano dopo quelli del ":  						$messaggio = " ils finissaient après ceux de "; break;
case " e vi erano":  										$messaggio = " et il y avait"; break;
case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = " réservations qui finissaient après le limite posé à reservations "; break;
case ", queste prenotazioni non sono state importate":		$messaggio = ", ces réservations n'ont pas été importées"; break;
case "Anno già creato": 						$messaggio = "Année déjà créée"; break;
case " Do":  									$messaggio = " Di"; break;
case " Lu":  									$messaggio = " Lu"; break;
case " Ma":  									$messaggio = " Ma"; break;
case " Me":  									$messaggio = " Me"; break;
case " Gi":  									$messaggio = " Jd"; break;
case " Ve":  									$messaggio = " Vd"; break;
case " Sa":  									$messaggio = " Sa"; break;
case "Gen":  									$messaggio = "Jan"; break;
case "Feb":  									$messaggio = "Fév"; break;
case "Mar":  									$messaggio = "Mars"; break;
case "Apr":  									$messaggio = "Avr"; break;
case "Mag":  									$messaggio = "Mai"; break;
case "Giu":  									$messaggio = "Juin"; break;
case "Lug":  									$messaggio = "Juil"; break;
case "Ago":  									$messaggio = "Août"; break;
case "Set":  									$messaggio = "Sep"; break;
case "Ott":  									$messaggio = "Oct"; break;
case "Nov":  									$messaggio = "Nov"; break;
case "Dic":  									$messaggio = "Déc"; break;
case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "Le format de l'année demandée est erroné"; break;
case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "Des mois ont été incorrectement choisis, ils ont été insérés à partir de janvier à décembre"; break;
case "Cognome del cliente":  					$messaggio = "Nom du client"; break;
case "Data iniziale":  							$messaggio = "Date de début"; break;
case "Data finale":  							$messaggio = "Date de fin"; break;
case "Tariffa completa":  						$messaggio = "Tarif complet"; break;
case "Da pagare":  								$messaggio = "À payer"; break;
case "Pers":  									$messaggio = "Pers"; break;
case "Registra":  								$messaggio = "Enregistrer"; break;
case "Entrata":  								$messaggio = "Entrée"; break;
case "Uscita":  								$messaggio = "Sortie"; break;
case "Entrata e pagato":  						$messaggio = "Entrée et payé"; break;
case "Uscita e pagato":  						$messaggio = "Sortie et payé"; break;
case "mostra tutte le date":  			$messaggio = "montrer toutes les dates"; break;
case "Utente":  				$messaggio = "Utilisateur"; break;
case "Esci":  					$messaggio = "Se déconnecter"; break;
case "<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al":	$messaggio = "<span class=\"colred\">Attention</span>: nous vous conseillons d'attendre jusqu'au"; break;
case "per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "pour créer la nouvelle année, en attendant vous pouvez ajouter des périodes au-delà"; break;
case "dalla":  					$messaggio = "du"; break;
case "tabella con i periodi e le tariffe":  	$messaggio = "table avec les périodes et les tarifs"; break;
case "anche senza creare un nuovo anno":  	$messaggio = "même sans créer une nouvelle année"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "Je n'ai pas de droits d'écriture sur le dossier de données"; break;
case "le statistiche":  			$messaggio = "les statistiques"; break;
case "inventario e magazzini":  		$messaggio = "stocks et entrepôts"; break;
case "obsoleti":  				$messaggio = "obsolète"; break;
case "Ultimo aggiornamento":  			$messaggio = "Dernière mise à jour"; break;
case "Aggiorna":  				$messaggio = "Mettre à jour"; break;
case "i documenti salvati":  			$messaggio = "documents enregistés"; break;
case "Punto vendita":  				$messaggio = "Point de vente"; break;
case "Non ho i permessi per creare nuove tabelle nel database":	$messaggio = "Je n'ai pas la permission de créer de nouvelles tables dans la base de données"; break;
case "Benvenuto a HOTELDRUID":  		$messaggio = "Bienvenue chez HOTELDRUID"; break;
case "Scegli la lingua":  			$messaggio = "Choisir la langue"; break;
case "crea il database":  			$messaggio = "créer la base de données"; break;
case "Promemoria":  				$messaggio = "Rappel"; break;
case "N&deg;":  				$messaggio = "N&deg;"; break;
case "Messaggi":  				$messaggio = "Messages"; break;
case "Questo utente non ha i privilegi per creare nuovi anni":	$messaggio = "This user has no privileges to create new years"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "nel database sono ancora disponibili periodi solo per meno di":	$messaggio = "in the database there are still available periods for only less than"; break;
case "mesi":  					$messaggio = "months"; break;
case "OK, ho capito":  				$messaggio = "OK, got it"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-fr_3.0.8-1.tar.gz: fr/inizio.php <==
<?php

switch ($messaggio) {

case "Menù principale dell'anno":             	$messaggio = "Menu principal de l'année"; break;
case "Inserisci una nuova prenotazione":      	$messaggio = "Insérer une nouvelle réservation"; break;
case "prenotazioni del mese di": 		$messaggio = "réservations mois de"; break;
case "visualizza": 				$messaggio = "voir"; break;
case "Gennaio":                               	$messaggio = "Janvier"; break;
case "Febbraio":                              	$messaggio = "Février"; break;
case "Marzo":                                 	$messaggio = "Mars"; break;
case "Aprile":      							$messaggio = "Avril"; break;
case "Maggio":                           		$messaggio = "Mai"; break;
case "Giugno":                            		$messaggio = "Juin"; break;
case "Luglio":                            		$messaggio = "Juillet"; break;
case "Agosto":  								$messaggio = "Août"; break;
case "Settembre":  								$messaggio = "Septembre"; break;
case "Ottobre":  								$messaggio = "Octobre"; break;
case "Novembre":  								$messaggio = "Novembre"; break;
case "Dicembre":  								$messaggio = "Décembre"; break;
case "tabella con":  				$messaggio = "tableau avec"; break;
case "tutte le prenotazioni":  					$messaggio = "toutes les réservations"; break;
case "le spese e le entrate":  					$messaggio = "dépenses et recettes"; break;
case "i periodi e le tariffe":  				$messaggio = "les périodes et les prix"; break;
case "tutti i clienti":  						$messaggio = "tous les clients"; break;
case "le regole di assegnazione":  				$messaggio = "les règles d'attribution"; break;
case "Inserisci un nuovo cliente":		$messaggio = "Insérer un nouveau client"; break;
case "Spese ed entrate":  			$messaggio = "dépenses et recettes"; break;
case "disponibilità dal":  			$messaggio = "disponibilités du"; break;
case "al":  									$messaggio = "au"; break;
case "per":  									$messaggio = "pour"; break;
case "persone":	  								$messaggio = "personnes"; break;
case "controlla":  				$messaggio = "vérifier"; break;
case "Inserisci o modifica i prezzi":  			$messaggio = "Insérer ou modifier les prix"; break;
case "Inserisci o modifica le regole di assegnazione":  $messaggio = "Insérer ou modifier les règles d'attribution"; break;
case "Configura e personalizza":				$messaggio = "Configurer et personnaliser"; break;
case "richiedi l'anno":  						$messaggio = "Aller à l'année"; break;
case "vai":  									$messaggio = "go"; break;
case "Non esiste l'anno ":  					$messaggio = "L'année "; break;
case " nel database":  							$messaggio = " n'existe pas dans la base de données"; break;
case "Crea l'anno":  							$messaggio = "Créer l'année"; break;
case "Domenica":  								$messaggio = "Dimanche"; break;
case "Lunedì":  								$messaggio = "Lundi"; break;
case "Martedì":  								$messaggio = "Mardi"; break;
case "Mercoledì":  								$messaggio = "Mercredi"; break;
case "Giovedì":  								$messaggio = "Jeudi"; break;
case "Venerdì":  								$messaggio = "Vendredi"; break;
case "Sabato":	 		 						$messaggio = "Samedi"; break;
case "come giorno di inizio/fine locazione":	$messaggio = "jour de début/fin de location"; break;
case "con periodi":  							$messaggio = "avec"; break;
case "settimanali":  							$messaggio = "périodes hebdomadaires"; break;
case "giornalieri":  							$messaggio = "périodes quotidiennes"; break;
case "e prenotazioni da":  						$messaggio = "et réservations de"; break;
case "a":  										$messaggio = "à"; break;
case "anno successivo": 			$messaggio = "année suivante"; break;
case "anni successivi":  			$messaggio = "années suivantes"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi), privilegi degli utenti e regole d'assegnazione.":  $messaggio = "Importation des réservations d'année précédente, des prix (inclus les surcoûts), des privilèges d'utilisateurs et des règles d'attribution."; break;
case "Anno ":  									$messaggio = "Année "; break;
case " creato":  								$messaggio = " créé"; break;
case "Non ci sono periodi che riguardano il ":  $messaggio = "Il n'y a aucune période concernant "; break;
case " nel ":  									$messaggio = " dans "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3":	$messaggio = ", ou le jour de la location de commencer/extrémité était différent, seulement des données au sujet des surcoûts, du dépôt, des noms des prix, des privilèges et des règles 2 et 3 d'utilisateurs des règles d'attribution ont été importées"; break;
case "Attenzione</b></font>: i periodi del ":  		$messaggio = "Attention</b></font> : les périodes de "; break;
case " finivano dopo quelli del ":  						$messaggio = " ils finissaient après ceux de "; break;
case " e vi erano":  										$messaggio = " et il y avait"; break;
case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = " réservations qui finissaient après le limite posé à reservations "; break;
case ", queste prenotazioni non sono state importate":		$messaggio = ", ces réservations n'ont pas été importées"; break;
case "Anno già creato": 						$messaggio = "Année déjà créée"; break;
case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "Le format de l'année demandée est erroné"; break;
case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "Des mois ont été incorrectement choisis, ils ont été insérés à partir de janvier à décembre"; break;
case "Cognome del cliente":  					$messaggio = "Nom du client"; break;
case "Data iniziale":  							$messaggio = "Date de début"; break;
case "Data finale":  							$messaggio = "Date de fin"; break;
case "Tariffa completa":  						$messaggio = "Tarif complet"; break;
case "Da pagare":  								$messaggio = "À payer"; break;
case "Pers":  									$messaggio = "Pers"; break;
case "Registra":  								$messaggio = "Enregistrer"; break;
case "Entrata":  								$messaggio = "Entrée"; break;
case "Uscita":  								$messaggio = "Sortie"; break;
case "Entrata e pagato":  						$messaggio = "Entrée et payé"; break;
case "Uscita e pagato":  						$messaggio = "Sortie et payé"; break;
case "mostra tutte le date":  			$messaggio = "montrer toutes les dates"; break;
case "Utente":  				$messaggio = "Utilisateur"; break;
case "Esci":  					$messaggio = "Se déconnecter"; break;
case "<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al":	$messaggio = "<span class=\"colred\">Attention</span>: nous vous conseillons d'attendre jusqu'au"; break;
case "per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "pour créer la nouvelle année, en attendant vous pouvez ajouter des périodes au-delà"; break;
case "dalla":  					$messaggio = "du"; break;
case "tabella con i periodi e le tariffe":  	$messaggio = "table avec les périodes et les tarifs"; break;
case "anche senza creare un nuovo anno":  	$messaggio = "même sans créer une nouvelle année"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "Je n'ai pas de droits d'écriture sur le dossier de données"; break;
case "le statistiche":  			$messaggio = "les statistiques"; break;
case "inventario e magazzini":  		$messaggio = "stocks et entrepôts"; break;
case "obsoleti":  				$messaggio = "obsolète"; break;
case "Ultimo aggiornamento":  			$messaggio = "Dernière mise à jour"; break;
case "Aggiorna":  				$messaggio = "Mettre à jour"; break;
case "i documenti salvati":  			$messaggio = "documents enregistés"; break;
case "Punto vendita":  				$messaggio = "Point de vente"; break;
case "Non ho i permessi per creare nuove tabelle nel database":	$messaggio = "Je n'ai pas la permission de créer de nouvelles tables dans la base de données"; break;
case "Benvenuto a HOTELDRUID":  		$messaggio = "Bienvenue chez HOTELDRUID"; break;
case "Scegli la lingua":  			$messaggio = "Choisir la langue"; break;
case "crea il database":  			$messaggio = "créer la base de données"; break;
case "Promemoria":  				$messaggio = "Rappel"; break;
case "N&deg;":  				$messaggio = "N&deg;"; break;
case "Messaggi":  				$messaggio = "Messages"; break;
case "Questo utente non ha i privilegi per creare nuovi anni":	$messaggio = "This user has no privileges to create new years"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "nel database sono ancora disponibili periodi solo per meno di":	$messaggio = "in the database there are still available periods for only less than"; break;
case "mesi":  					$messaggio = "months"; break;
case "OK, ho capito":  				$messaggio = "OK, got it"; break;
case "Crea Anno":  				$messaggio = "Create Year"; break;
case "Nota":  					$messaggio = "Notice"; break;
case "l'anno":  				$messaggio = "year"; break;
case "verrà archiviato automaticamente il":  	$messaggio = "will be automatically archived on"; break;
case "nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "meanwhile you can add periods beyond"; break;
case "ricordarsi di tornare al":  		$messaggio = "remember to come back to"; break;
case "una volta conclusa la consultazione del":	$messaggio = "once finished consulting the"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
